@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,34 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
-from .common import (
-    RelatedUrl,
-    Signature,
-)
 from .attestation import (
     AttestationNote,
     AttestationOccurrence,
 )
-from .provenance import (
-    BuildProvenance,
-    Source,
-    FileHashes,
-    Hash,
-    Command,
-    Artifact,
-    SourceContext,
-    AliasContext,
-    CloudRepoSourceContext,
-    GerritSourceContext,
-    GitSourceContext,
-    RepoId,
-    ProjectRepoId,
-)
 from .build import (
     BuildNote,
     BuildOccurrence,
 )
+from .common import (
+    RelatedUrl,
+    Signature,
+    NoteKind,
+)
 from .cvss import CVSSv3
 from .deployment import (
     DeploymentNote,
@@ -51,11 +35,34 @@ from .discovery import (
     DiscoveryNote,
     DiscoveryOccurrence,
 )
+from .grafeas import (
+    BatchCreateNotesRequest,
+    BatchCreateNotesResponse,
+    BatchCreateOccurrencesRequest,
+    BatchCreateOccurrencesResponse,
+    CreateNoteRequest,
+    CreateOccurrenceRequest,
+    DeleteNoteRequest,
+    DeleteOccurrenceRequest,
+    GetNoteRequest,
+    GetOccurrenceNoteRequest,
+    GetOccurrenceRequest,
+    ListNoteOccurrencesRequest,
+    ListNoteOccurrencesResponse,
+    ListNotesRequest,
+    ListNotesResponse,
+    ListOccurrencesRequest,
+    ListOccurrencesResponse,
+    Note,
+    Occurrence,
+    UpdateNoteRequest,
+    UpdateOccurrenceRequest,
+)
 from .image import (
-    Layer,
     Fingerprint,
     ImageNote,
     ImageOccurrence,
+    Layer,
 )
 from .package import (
     Distribution,
@@ -63,101 +70,97 @@ from .package import (
     PackageNote,
     PackageOccurrence,
     Version,
+    Architecture,
+)
+from .provenance import (
+    AliasContext,
+    Artifact,
+    BuildProvenance,
+    CloudRepoSourceContext,
+    Command,
+    FileHashes,
+    GerritSourceContext,
+    GitSourceContext,
+    Hash,
+    ProjectRepoId,
+    RepoId,
+    Source,
+    SourceContext,
 )
 from .upgrade import (
-    UpgradeNote,
     UpgradeDistribution,
-    WindowsUpdate,
+    UpgradeNote,
     UpgradeOccurrence,
+    WindowsUpdate,
 )
 from .vulnerability import (
     VulnerabilityNote,
     VulnerabilityOccurrence,
+    Severity,
 )
-from .grafeas import (
-    Occurrence,
-    Note,
-    GetOccurrenceRequest,
-    ListOccurrencesRequest,
-    ListOccurrencesResponse,
-    DeleteOccurrenceRequest,
-    CreateOccurrenceRequest,
-    UpdateOccurrenceRequest,
-    GetNoteRequest,
-    GetOccurrenceNoteRequest,
-    ListNotesRequest,
-    ListNotesResponse,
-    DeleteNoteRequest,
-    CreateNoteRequest,
-    UpdateNoteRequest,
-    ListNoteOccurrencesRequest,
-    ListNoteOccurrencesResponse,
-    BatchCreateNotesRequest,
-    BatchCreateNotesResponse,
-    BatchCreateOccurrencesRequest,
-    BatchCreateOccurrencesResponse,
-)
-
 
 __all__ = (
-    "RelatedUrl",
-    "Signature",
     "AttestationNote",
     "AttestationOccurrence",
-    "BuildProvenance",
-    "Source",
-    "FileHashes",
-    "Hash",
-    "Command",
-    "Artifact",
-    "SourceContext",
-    "AliasContext",
-    "CloudRepoSourceContext",
-    "GerritSourceContext",
-    "GitSourceContext",
-    "RepoId",
-    "ProjectRepoId",
     "BuildNote",
     "BuildOccurrence",
+    "RelatedUrl",
+    "Signature",
+    "NoteKind",
     "CVSSv3",
     "DeploymentNote",
     "DeploymentOccurrence",
     "DiscoveryNote",
     "DiscoveryOccurrence",
-    "Layer",
+    "BatchCreateNotesRequest",
+    "BatchCreateNotesResponse",
+    "BatchCreateOccurrencesRequest",
+    "BatchCreateOccurrencesResponse",
+    "CreateNoteRequest",
+    "CreateOccurrenceRequest",
+    "DeleteNoteRequest",
+    "DeleteOccurrenceRequest",
+    "GetNoteRequest",
+    "GetOccurrenceNoteRequest",
+    "GetOccurrenceRequest",
+    "ListNoteOccurrencesRequest",
+    "ListNoteOccurrencesResponse",
+    "ListNotesRequest",
+    "ListNotesResponse",
+    "ListOccurrencesRequest",
+    "ListOccurrencesResponse",
+    "Note",
+    "Occurrence",
+    "UpdateNoteRequest",
+    "UpdateOccurrenceRequest",
     "Fingerprint",
     "ImageNote",
     "ImageOccurrence",
+    "Layer",
     "Distribution",
     "Location",
     "PackageNote",
     "PackageOccurrence",
     "Version",
-    "UpgradeNote",
+    "Architecture",
+    "AliasContext",
+    "Artifact",
+    "BuildProvenance",
+    "CloudRepoSourceContext",
+    "Command",
+    "FileHashes",
+    "GerritSourceContext",
+    "GitSourceContext",
+    "Hash",
+    "ProjectRepoId",
+    "RepoId",
+    "Source",
+    "SourceContext",
     "UpgradeDistribution",
-    "WindowsUpdate",
+    "UpgradeNote",
     "UpgradeOccurrence",
+    "WindowsUpdate",
     "VulnerabilityNote",
     "VulnerabilityOccurrence",
-    "Occurrence",
-    "Note",
-    "GetOccurrenceRequest",
-    "ListOccurrencesRequest",
-    "ListOccurrencesResponse",
-    "DeleteOccurrenceRequest",
-    "CreateOccurrenceRequest",
-    "UpdateOccurrenceRequest",
-    "GetNoteRequest",
-    "GetOccurrenceNoteRequest",
-    "ListNotesRequest",
-    "ListNotesResponse",
-    "DeleteNoteRequest",
-    "CreateNoteRequest",
-    "UpdateNoteRequest",
-    "ListNoteOccurrencesRequest",
-    "ListNoteOccurrencesResponse",
-    "BatchCreateNotesRequest",
-    "BatchCreateNotesResponse",
-    "BatchCreateOccurrencesRequest",
-    "BatchCreateOccurrencesResponse",
+    "Severity",
 )
