@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
 
@@ -46,9 +44,8 @@ class RelatedUrl(proto.Message):
             Label to describe usage of the URL.
     """
 
-    url = proto.Field(proto.STRING, number=1)
-
-    label = proto.Field(proto.STRING, number=2)
+    url = proto.Field(proto.STRING, number=1,)
+    label = proto.Field(proto.STRING, number=2,)
 
 
 class Signature(proto.Message):
@@ -113,9 +110,8 @@ class Signature(proto.Message):
             -  "nih:///sha-256;703f68f42aba2c6de30f488a5ea122fef76324679c9bf89791ba95a1271589a5".
     """
 
-    signature = proto.Field(proto.BYTES, number=1)
-
-    public_key_id = proto.Field(proto.STRING, number=2)
+    signature = proto.Field(proto.BYTES, number=1,)
+    public_key_id = proto.Field(proto.STRING, number=2,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
